@@ -1,8 +1,8 @@
 /*
- * module.h - interface for module developers
- * This file is part of MSA program
+ * msa_module.h - interface for module developers
+ * This file is part of MySocials program
  *
- * Copyright (C) 2009 - Alexander V. Borodin
+ * Copyright (C) 2009, 2010 - Alexander V. Borodin
  *
  * MSA program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -61,6 +61,7 @@
 #define CLASS_FRIENDS "friends"
 #define GET_FRIENDS "getListFriends"
 #define UPDATE_FRIENDS "updateListFriends"
+#define DELETE_FRIEND "deleteFriend"
 
 #define CLASS_BOX_MESSAGE "messages"
 #define UPDATE_INBOX_MESSAGES "updateInboxMessages"
@@ -68,6 +69,7 @@
 #define GET_INBOX_MESSAGES "getInboxMessages"
 #define GET_OUTBOX_MESSAGES "getOutboxMessages"
 #define GET_NEW_MESSAGES "getNewInboxMessages"
+#define DELETE_MESSAGE "deleteMessage"
 
 #define CLASS_MESSAGES "systemMessages"
 #define INFO_MESSAGE "infoMessage"
@@ -101,6 +103,7 @@
 #define DB_GET_ERROR_INBOX_MESSAGE_CODE "335"
 #define DB_NEW_INBOX_MESSAGES_CODE "341"
 #define DB_INIT_ERROR_CODE "351"
+#define DB_ERROR_SEARCH_FRIENDS_CODE "361"
 
 /** db message text **/
 #define DB_SAVE_MESSAGE_PROFILE_TEXT _("profile updated")
@@ -109,10 +112,11 @@
 #define DB_SAVE_MESSAGE_FRIENDS_TEXT _("friends list updated")
 #define DB_SAVE_ERROR_FRIENDS_TEXT _("friends list wasn't updated")
 #define DB_GET_ERROR_FRIENDS_TEXT _("friends list wasn't found")
-#define DB_SAVE_MESSAGE_FRIENDS_PROFILE_TEXT _("friend's profile updated")
-#define DB_SAVE_ERROR_FRIENDS_PROFILE_TEXT _("friend's profile wasn't updated")
+#define DB_SAVE_MESSAGE_FRIENDS_PROFILE_TEXT _("profile updated")
+#define DB_SAVE_ERROR_FRIENDS_PROFILE_TEXT _("profile wasn't updated")
 #define DB_GET_ERROR_BINARY_TEXT _("image wasn't found")
 #define DB_SAVE_ERROR_BINARY_TEXT _("image wasn't updated")
+#define DB_ERROR_SEARCH_FRIENDS_TEXT _("friends no found")
 
 #define DB_GET_ERROR_INBOX_MESSAGES_TEXT _("inbox messages list wasn't found")
 #define DB_GET_ERROR_OUTBOX_MESSAGES_TEXT _("outbox messages list wasn't found")
@@ -126,33 +130,21 @@
 #define DB_NEW_INBOX_MESSAGES_TEXT _("new messages:")
 #define DB_INIT_ERROR_TEXT _("db critical error")
 
-/** Driver message code **/
-#define DRV_SETT_ERROR_CODE "409"
-#define DRV_SETT_SAVED_CODE "410"
-#define DRV_AUTH_ERROR_CODE "407"
-#define DRV_REQ_ERROR_CODE "402"
-#define DRV_PROF_SAVED_CODE "400"
-#define DRV_CAPT_ERROR_CODE "408"
-#define DRV_RESP_ERROR_CODE "403"
-#define DRV_NETW_ERROR_CODE "404"
-#define DRV_MESS_SEND_CODE "401"
-#define DRV_MESS_ERROR_CODE "405"
-#define DRV_ACCESS_ERROR_CODE "406"
-#define DRV_SERVER_ERROR_CODE "411"
-
-/** Driver message text **/
-#define DRV_SETT_ERROR _("Unable to save settings")
-#define DRV_SETT_SAVED _("Settings saved")
-#define DRV_AUTH_ERROR _("Authorization problem")
-#define DRV_REQ_ERROR _("Unable to perform request")
-#define DRV_PROF_SAVED _("Profile changed")
-#define DRV_CAPT_ERROR _("Captcha")
-#define DRV_RESP_ERROR _("Bad response from server")
-#define DRV_NETW_ERROR _("Network problem")
-#define DRV_MESS_SEND _("Message send")
-#define DRV_MESS_ERROR _("Unable send message")
-#define DRV_ACCESS_ERROR _("Operation prohibited by privacy")
-#define DRV_SERVER_ERROR _("Internal Server Error")
+#ifndef _MSA_MODULE
+#define _MSA_MODULE
+/* Error Code */
+typedef enum error_type
+{
+    FAILURE = -1,
+    NO_ERRORS = 0,
+    SUCCESS = 0,
+    ERROR_ALLOCATION_OF_MEMORY,
+    ERROR_NO_DRIVER_FUNCTION,
+    ERROR_INITIALIZATION_ALREADY_PASSED,
+    ERROR_DRIVER_IS_BUSY,
+    ERROR_CANT_SEND_DATA,
+    ERROR_CANT_PARSE_DATA
+} error_type ;
 
 /** @enum msa_module_type
  *  @brief List of module types
@@ -260,6 +252,6 @@ typedef struct _msa_module {
     int (*shutdown)();
 
 } msa_module;
-
+#endif /*_MSA_MODULE*/
 
 #endif
