@@ -255,16 +255,18 @@ void callback_button_friends_get(GtkWidget* button, gpointer data)
     
     gchar *sfrom = g_strdup_printf("%d", from);
     gchar *sto = g_strdup_printf("%d", to);
+    gchar *sonline = g_strdup_printf("%d", online);
     gchar *request = g_strconcat("<?xml version=\"1.0\"?><TransitData id=\"1\" \
     type=\"data\"><SourceID>ui</SourceID>\
     <TargetID>db</TargetID>\
     <Content><Request class=\"friends\" function = \"getListFriends\"><Params From=\"", sfrom,
-    "\" To=\"", sto, "\" Sort=\"", str_sort, "\" Online=\"",g_strdup_printf("%d", online),"\"/></Request></Content></TransitData>", NULL);
+    "\" To=\"", sto, "\" Sort=\"", str_sort, "\" Online=\"", sonline,"\"/></Request></Content></TransitData>", NULL);
     kernel->send(xmlParseDoc(request), NULL, NULL);
     g_free(request);
     g_free(sfrom);
     g_free(str_sort);
     g_free(sto);
+    g_free(sonline);
     //g_print("GETTING FRIENDS FROM %d to %d\n", from + 1, to + 1);
 }
 
@@ -300,6 +302,7 @@ void callback_friends_filter(gchar* str_filter)
         gtk_widget_hide(ui_data->box_friends_navi);
         gtk_widget_hide(ui_data->button_friends_show_offl);        
         gtk_label_set_text(GTK_LABEL(ui_data->label_friends_filter), g_strconcat(STR_RSLT, " \"", str_filter, "\"", NULL));
+        gtk_label_set_ellipsize(GTK_LABEL(ui_data->label_friends_filter), PANGO_ELLIPSIZE_END);
         gtk_widget_show_all(ui_data->box_friends_result);
     } else {
         gtk_widget_show_all(ui_data->box_friends_navi);
@@ -326,6 +329,7 @@ void callback_button_friends_result(GtkWidget* button_cb, gpointer data)
 **/
 void callback_button_friends_update(GtkWidget* button, gpointer data)
 {
+    callback_button_friends_result(NULL, NULL);
     xmlDocPtr resp = NULL;
    //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
     kernel->send(xmlParseDoc("<?xml version=\"1.0\"?><TransitData id=\"1\" \
@@ -1291,6 +1295,7 @@ void callback_task_switch(GtkWidget* notebook, GtkNotebookPage* page, guint page
         ui_data->empty_messages = TRUE;
         break;
     case 1:
+        callback_friends_filter(NULL);
         callback_button_friends_get(NULL, NULL);
         str_title = g_strconcat(STR_PROG, STR_TTLS, STR_FRDS, NULL);
         ui_data->empty_messages = TRUE;
