@@ -125,7 +125,7 @@ static void ui_init_tasks()
     //hildon_button_set_image(ui_data->button_friends_page_last, gtk_image_new_from_icon_name("pdf_viewer_last_page", GTK_ICON_SIZE_SMALL_TOOLBAR));
     gtk_box_pack_start(GTK_BOX(box_friends_show_offl), ui_data->button_friends_show_offl, TRUE, TRUE, 0); 
     gtk_box_pack_start(GTK_BOX(box_friends_tool), box_friends_show_offl, TRUE, TRUE, 0); 
-    gtk_box_pack_start(GTK_BOX(box_friends_tool), ui_data->box_friends_navi, FALSE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(box_friends_tool), ui_data->box_friends_navi, TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(ui_data->box_friends_navi), ui_data->button_friends_page_frst, FALSE, FALSE, 0); 
     gtk_box_pack_start(GTK_BOX(ui_data->box_friends_navi), ui_data->button_friends_page_prev, FALSE, FALSE, 0); 
     gtk_box_pack_start(GTK_BOX(ui_data->box_friends_navi), ui_data->label_friends_page, TRUE, TRUE, 0); 
@@ -139,6 +139,10 @@ static void ui_init_tasks()
     /* FRIENDS FILTER */
     ui_data->box_friends_result = gtk_hbox_new(FALSE, PADDING);
     ui_data->label_friends_filter = gtk_label_new(NULL);
+    //gtk_misc_set_alignment(GTK_MISC(ui_data->label_friends_filter), 1, 0.5);
+    //gtk_label_set_line_wrap(GTK_LABEL(ui_data->label_friends_filter), FALSE);
+    //gtk_label_set_single_line_mode(GTK_LABEL(ui_data->label_friends_filter), TRUE);
+    
     GtkWidget* button_friends_result = GTK_WIDGET(hildon_button_new(HILDON_SIZE_FINGER_HEIGHT, NULL));
     gtk_button_set_relief(GTK_BUTTON(button_friends_result), GTK_RELIEF_NONE);
     g_signal_connect(G_OBJECT(button_friends_result), "clicked", G_CALLBACK(callback_button_friends_result), NULL);
@@ -146,7 +150,7 @@ static void ui_init_tasks()
     //gtk_container_add(GTK_CONTAINER(button_friends_result), gtk_image_new_from_file(IMG_CLER));
     gtk_box_pack_start(GTK_BOX(ui_data->box_friends_result), ui_data->label_friends_filter, TRUE, TRUE, 0); 
     gtk_box_pack_start(GTK_BOX(ui_data->box_friends_result), button_friends_result, FALSE, FALSE, 0); 
-    gtk_box_pack_start(GTK_BOX(box_friends_tool), ui_data->box_friends_result, FALSE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(box_friends_list), ui_data->box_friends_result, FALSE, TRUE, 0);
     /* FRIENDS TASKS */
     GtkWidget* box_friends_tasks = gtk_vbox_new(TRUE, 0);
     gtk_box_pack_start(GTK_BOX(ui_data->box_friends), box_friends_tasks, FALSE, TRUE, 0);
@@ -209,14 +213,18 @@ static void ui_init_tasks()
     GtkWidget* box_msgs_page = gtk_hbox_new(FALSE, 0);
     GtkWidget* rb1 = GTK_WIDGET(hildon_gtk_radio_button_new(HILDON_SIZE_FINGER_HEIGHT, NULL));
     GtkWidget* rb2 = GTK_WIDGET(hildon_gtk_radio_button_new_from_widget(HILDON_SIZE_FINGER_HEIGHT, GTK_RADIO_BUTTON(rb1)));
+    GtkWidget* rb3 = GTK_WIDGET(hildon_gtk_radio_button_new_from_widget(HILDON_SIZE_FINGER_HEIGHT, GTK_RADIO_BUTTON(rb1)));
     //gtk_button_set_label(GTK_BUTTON(rb1), _(STR_INCM));
     gtk_button_set_image(rb1, gtk_image_new_from_icon_name("email_inbox", GTK_ICON_SIZE_BUTTON));
     gtk_button_set_image(rb2, gtk_image_new_from_icon_name("general_outbox", GTK_ICON_SIZE_BUTTON));
+    gtk_button_set_image(rb3, gtk_image_new_from_icon_name("chat_failed_sms", GTK_ICON_SIZE_BUTTON));
     //gtk_button_set_label(GTK_BUTTON(rb2), _(STR_SENT));
     gtk_box_pack_start(GTK_BOX(box_msgs_type), GTK_WIDGET(rb1), TRUE, TRUE, 0);
-    gtk_box_pack_end(GTK_BOX(box_msgs_type), GTK_WIDGET(rb2), TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(box_msgs_type), GTK_WIDGET(rb2), TRUE, TRUE, 0);
+    gtk_box_pack_end(GTK_BOX(box_msgs_type), GTK_WIDGET(rb3), TRUE, TRUE, 0);
     gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(rb1), FALSE);
-    gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(rb2), FALSE);    
+    gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(rb2), FALSE); 
+    gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(rb3), FALSE);    
     ui_data->button_messages_page_prev = hildon_button_new(HILDON_SIZE_FINGER_HEIGHT, NULL);
     ui_data->button_messages_page_next = hildon_button_new(HILDON_SIZE_FINGER_HEIGHT, NULL);
     gtk_button_set_relief(GTK_WIDGET(ui_data->button_messages_page_prev), GTK_RELIEF_NONE);
